pub struct HostAllowlist { /* private fields */ }Expand description
Host allowlist for redirect middleware.
Pass this type to redirect middleware setter methods such as
crate::middleware::RedirectHttps::allow_hosts to require request hosts to match a known
allowlisted value before constructing an absolute redirect target.
Host matching is case-insensitive. Include ports in allowlist entries when your deployment expects them.
Implementations